@@ -391,19 +391,25 @@ class WSGITask(Task):
         # Call the application to handle the request and write a response
         app_iter = self.channel.server.application(env, start_response)
 
-        try:
-            if app_iter.__class__ is ReadOnlyFileBasedBuffer:
-                cl = self.content_length
-                size = app_iter.prepare(cl)
-                if size:
-                    if cl != size:
-                        if cl is not None:
-                            self.remove_content_length_header()
-                        self.content_length = size
-                    self.write(b'') # generate headers
-                    self.channel.write_soon(app_iter)
-                    return
+        if app_iter.__class__ is ReadOnlyFileBasedBuffer:
+            # NB: do not put this inside the below try: finally: which closes
+            # the app_iter; we need to defer closing the underlying file.  It's
+            # intention that we don't want to call ``close`` here if the
+            # app_iter is a ROFBB; the buffer (and therefore the file) will
+            # eventually be closed within channel.py's _flush_some or
+            # handle_close instead.
+            cl = self.content_length
+            size = app_iter.prepare(cl)
+            if size:
+                if cl != size:
+                    if cl is not None:
+                        self.remove_content_length_header()
+                    self.content_length = size
+                self.write(b'') # generate headers
+                self.channel.write_soon(app_iter)
+                return
 
+        try:
             first_chunk_len = None
             for chunk in app_iter:
                 if first_chunk_len is None:
@@ -483,9 +489,17 @@ class WSGITask(Task):
         environ['SCRIPT_NAME'] = url_prefix
         environ['PATH_INFO'] = path
         environ['QUERY_STRING'] = request.query
-        environ['REMOTE_ADDR'] = channel.addr[0]
+        host = environ['REMOTE_ADDR'] = channel.addr[0]
 
-        for key, value in request.headers.items():
+        headers = dict(request.headers)
+        if host == server.adj.trusted_proxy:
+            wsgi_url_scheme = headers.pop('X_FORWARDED_PROTO',
+                                          request.url_scheme)
+        else:
+            wsgi_url_scheme = request.url_scheme
+        if wsgi_url_scheme not in ('http', 'https'):
+            raise ValueError('Invalid X_FORWARDED_PROTO value')
+        for key, value in headers.items():
             value = value.strip()
             mykey = rename_headers.get(key, None)
             if mykey is None:
@@ -495,7 +509,7 @@ class WSGITask(Task):
 
         # the following environment variables are required by the WSGI spec
         environ['wsgi.version'] = (1, 0)
-        environ['wsgi.url_scheme'] = request.url_scheme
+        environ['wsgi.url_scheme'] = wsgi_url_scheme
         environ['wsgi.errors'] = sys.stderr # apps should use the logging module
         environ['wsgi.multithread'] = True
         environ['wsgi.multiprocess'] = False
